@@ -17,8 +17,8 @@
 # @author: Tatiana Mazur
 
 
-from django.core.urlresolvers import reverse_lazy  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse_lazy
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
@@ -28,27 +28,6 @@ from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.vpn import tables
 
 
-def get_resource_or_fake(request, base_obj, resource, api_module):
-    """Return a resource detail or a fake object if it fails.
-
-    This methods retrieves a specified resource of base_obj.
-    It gets the resource ID from base_obj.<resource>_id and then
-    calls api_module.<resource>_get(resource_id).
-    If the api call fails, it returns a fake object which contains
-    only resource_id for the specified resouce.
-    The retrieved object is set to base_obj.<resource>.
-    """
-    obj_id = getattr(base_obj, '%s_id' % resource)
-    try:
-        obj_getter = getattr(api_module, '%s_get' % resource)
-        obj = obj_getter(request, obj_id)
-        setattr(base_obj, resource, obj)
-    except Exception:
-        fake_dict = {'id': obj_id, 'name': ''}
-        setattr(base_obj, resource,
-                api.neutron.NeutronAPIDictWrapper(fake_dict))
-
-
 class IPSecSiteConnectionsTab(tabs.TableTab):
     table_classes = (tables.IPSecSiteConnectionsTable,)
     name = _("IPSec Site Connections")
@@ -58,15 +37,15 @@ class IPSecSiteConnectionsTab(tabs.TableTab):
     def get_ipsecsiteconnectionstable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            ipsecsiteconnections = api.vpn.ipsecsiteconnections_get(
+            ipsecsiteconnections = api.vpn.ipsecsiteconnection_list(
                 self.tab_group.request, tenant_id=tenant_id)
-            ipsecsiteconnectionsFormatted = [s.readable(self.tab_group.request)
-                for s in ipsecsiteconnections]
         except Exception:
-            ipsecsiteconnectionsFormatted = []
+            ipsecsiteconnections = []
             exceptions.handle(self.tab_group.request,
                 _('Unable to retrieve IPSec Site Connections list.'))
-        return ipsecsiteconnectionsFormatted
+        for c in ipsecsiteconnections:
+            c.set_id_as_name_if_empty()
+        return ipsecsiteconnections
 
 
 class VPNServicesTab(tabs.TableTab):
@@ -78,15 +57,15 @@ class VPNServicesTab(tabs.TableTab):
     def get_vpnservicestable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            vpnservices = api.vpn.vpnservices_get(
+            vpnservices = api.vpn.vpnservice_list(
                 self.tab_group.request, tenant_id=tenant_id)
-            vpnservicesFormatted = [s.readable(self.tab_group.request) for
-                              s in vpnservices]
         except Exception:
-            vpnservicesFormatted = []
+            vpnservices = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve VPN Services list.'))
-        return vpnservicesFormatted
+        for s in vpnservices:
+            s.set_id_as_name_if_empty()
+        return vpnservices
 
 
 class IKEPoliciesTab(tabs.TableTab):
@@ -98,12 +77,14 @@ class IKEPoliciesTab(tabs.TableTab):
     def get_ikepoliciestable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            ikepolicies = api.vpn.ikepolicies_get(
+            ikepolicies = api.vpn.ikepolicy_list(
                 self.tab_group.request, tenant_id=tenant_id)
         except Exception:
             ikepolicies = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve IKE Policies list.'))
+        for p in ikepolicies:
+            p.set_id_as_name_if_empty()
         return ikepolicies
 
 
@@ -116,12 +97,14 @@ class IPSecPoliciesTab(tabs.TableTab):
     def get_ipsecpoliciestable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            ipsecpolicies = api.vpn.ipsecpolicies_get(
+            ipsecpolicies = api.vpn.ipsecpolicy_list(
                 self.tab_group.request, tenant_id=tenant_id)
         except Exception:
             ipsecpolicies = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve IPSec Policies list.'))
+        for p in ipsecpolicies:
+            p.set_id_as_name_if_empty()
         return ipsecpolicies
 
 
@@ -188,14 +171,11 @@ class VPNServiceDetailsTab(tabs.Tab):
             msg = _('Unable to retrieve VPN Service details.')
             exceptions.handle(request, msg, redirect=self.failure_url)
         try:
-            connections = api.vpn.ipsecsiteconnections_get(
+            connections = api.vpn.ipsecsiteconnection_list(
                 request, vpnservice_id=sid)
             vpnservice.vpnconnections = connections
         except Exception:
             vpnservice.vpnconnections = []
-
-        get_resource_or_fake(request, vpnservice, 'router', api.neutron)
-        get_resource_or_fake(request, vpnservice, 'subnet', api.neutron)
         return {'vpnservice': vpnservice}
 
 
@@ -217,10 +197,6 @@ class IPSecSiteConnectionDetailsTab(tabs.Tab):
         except Exception:
             msg = _('Unable to retrieve IPSec Site Connection details.')
             exceptions.handle(request, msg, redirect=self.failure_url)
-
-        get_resource_or_fake(request, ipsecsiteconn, 'vpnservice', api.vpn)
-        get_resource_or_fake(request, ipsecsiteconn, 'ipsecpolicy', api.vpn)
-        get_resource_or_fake(request, ipsecsiteconn, 'ikepolicy', api.vpn)
         return {'ipsecsiteconnection': ipsecsiteconn}
 
 
